usr/lib/linux-kbuild-{{abiname}}/scripts                          usr/src/{{package}}/scripts
usr/lib/linux-kbuild-{{abiname}}/tools                            usr/src/{{package}}/tools
usr/src/{{package}}                                               usr/lib/modules/{{abiname}}{{localversion}}/build
usr/src/linux-headers-{{abiname}}-common{{localversion_headers}}  usr/lib/modules/{{abiname}}{{localversion}}/source
