# Add symlinks to vmlinux from the locations expected by kdump-tools,
# systemtap and others
usr/lib/debug/boot/vmlinux-{{abiname}}{{localversion}}  usr/lib/debug/vmlinux-{{abiname}}{{localversion}}
usr/lib/debug/boot/vmlinux-{{abiname}}{{localversion}}  usr/lib/debug/lib/modules/{{abiname}}{{localversion}}/vmlinux
