boot/config-*
boot/System.map-*
lib/modules/{{abiname}}{{localversion}}/modules.*  usr/lib/modules/{{abiname}}{{localversion}}
{% if config.build.enable_dtb %}
lib/modules/{{abiname}}{{localversion}}/dtb        usr/lib/modules/{{abiname}}{{localversion}}
{% endif %}
